%global _hardened_build 1
%global debug_package %{nil}
%global srcname ejabberd


Name:           ejabberd
Version:        16.09
Release:        %mkrel 4


Group:          System/Servers

Summary:        A distributed, fault-tolerant Jabber/XMPP server
License:        GPLv2+
URL:            http://www.ejabberd.im/
VCS:            scm:git:https://github.com/processone/ejabberd.git
Source0:        https://github.com/processone/%{name}/archive/%{version}.tar.gz
Source2:        ejabberd.logrotate

# Support for systemd
Source4:        ejabberd.service
Source5:        ejabberd.tmpfiles.conf

# PAM support
Source9:        ejabberdctl.pam
Source11:       ejabberd.pam

# polkit support
Source12:       ejabberdctl.polkit.actions
Source13:       ejabberdctl.polkit.rules


# Use ejabberd as an example for PAM service name (fedora/epel-specific)
Patch1: ejabberd-0001-Fix-PAM-service-example-name-to-match-actual-one.patch
# polkit support
Patch2: ejabberd-0002-Enable-polkit-support.patch
# Fedora-specific
Patch3: ejabberd-0003-Install-into-BINDIR-instead-of-SBINDIR.patch
# Fedora-specific
Patch4: ejabberd-0004-Enable-systemd-notification-if-available.patch

BuildRequires:  elixir >= 1.2.6
BuildRequires:  erlang-cache_tab >= 1.0.4
BuildRequires:  erlang-esip >= 1.0.8
BuildRequires:  erlang-ezlib >= 1.0.1
BuildRequires:  erlang-fast_tls >= 1.0.7
BuildRequires:  erlang-fast_xml >= 1.1.15
BuildRequires:  erlang-fast_yaml >= 1.0.6
BuildRequires:  erlang-iconv >= 1.0.2
BuildRequires:  erlang-jiffy >= 0.14.7
BuildRequires:  erlang-lager >= 3.2.1
BuildRequires:  erlang-luerl >= 0.2
BuildRequires:  erlang-meck >= 0.8.4
BuildRequires:  erlang-odbc
BuildRequires:  erlang-p1_mysql >= 1.0.1
BuildRequires:  erlang-p1_oauth2 >= 0.6.1
BuildRequires:  erlang-p1_pam >= 1.0.0
BuildRequires:  erlang-p1_pgsql >= 1.1.0
BuildRequires:  erlang-p1_utils >= 1.0.5
BuildRequires:  erlang-rebar
BuildRequires:  erlang-riak_client
BuildRequires:  erlang-sd_notify
BuildRequires:  erlang-stringprep >= 1.0.6
BuildRequires:  erlang-stun >= 1.0.7
BuildRequires:  expat-devel >= 1.95
BuildRequires:  git
BuildRequires:  yaml-devel >= 0.1.4
BuildRequires:  openssl-devel >= 1.0.0
BuildRequires:  pam-devel

BuildRequires:  hevea
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++

# For creating user and group
Requires(pre):  shadow-utils

Requires(post): /usr/bin/openssl
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Provides: user(%{name})
Provides: group(%{name})

# From rebar
Requires:   elixir >= 1.1.0
# for /usr/bin/pkexec
Requires:   polkit
# for flock in ejabberdctl
Requires:   util-linux


%description
ejabberd is a Free and Open Source distributed fault-tolerant
Jabber/XMPP server. It is mostly written in Erlang, and runs on many
platforms (tested on Linux, FreeBSD, NetBSD, Solaris, Mac OS X and
Windows NT/2000/XP).


%prep
%setup -q

%patch1 -p1 -b .pam_name
%patch2 -p1 -b .use_polkit
%patch3 -p1 -b .use_bindir
%patch4 -p1 -b .enable_sd_notify


%build
autoreconf -ivf

# Disabled: --enable-hipe --enable-roster-gateway-workaround --enable-transient_supervisors
#           --enable-full-xml --enable-mssql --enable-tools --enable-riak --enable-http
%configure2_5x --enable-odbc --enable-mysql --enable-pgsql --enable-pam --enable-zlib --enable-iconv --enable-debug --enable-lager --libdir=%{_libdir}/erlang/lib/ --with-erlang=%{_libdir}/erlang/

%{erlang_compile}


%install
%{erlang_install}

sed -e "s*{{rootdir}}*%{_prefix}*" \
    -e "s*{{installuser}}**" \
    -e "s*{{bindir}}*%{_bindir}*" \
    -e "s*{{libdir}}*%{_erllibdir}*" \
    -e "s*{{sysconfdir}}*%{_sysconfdir}*" \
    -e "s*{{localstatedir}}*/var*" \
    -e "s*{{docdir}}*%{_datadir}/doc/%{name}*" \
    -e "s*{{erl}}*%{_erldir}/bin/erl*" \
    -e "s*{{epmd}}*%{_erllibdir}/bin/epmd*" ejabberdctl.template \
> ejabberdctl.example

install -d -m 0750 %{buildroot}%{_sysconfdir}/%{name}
install -D -p -m 0644 ejabberd.yml.example %{buildroot}%{_sysconfdir}/%{name}/ejabberd.yml
install -D -p -m 0644 ejabberdctl.cfg.example %{buildroot}%{_sysconfdir}/%{name}/ejabberdctl.cfg
install -D -p -m 0644 inetrc %{buildroot}%{_sysconfdir}/%{name}/inetrc

install -D -p -m 0644 ejabberdctl.example %{buildroot}%{_bindir}/ejabberdctl

install -d -m 0750 %{buildroot}/var/lib/ejabberd
install -d -m 0750 %{buildroot}/var/lock/ejabberdctl
install -d -m 0750 %{buildroot}/var/log/ejabberd

# fix example SSL certificate path to real one, which we created recently (see above)
%{__perl} -pi -e 's!/path/to/ssl.pem!/etc/ejabberd/ejabberd.pem!g' %{buildroot}/etc/ejabberd/ejabberd.yml

install -D -p -m 0755 tools/captcha.sh %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/bin/captcha.sh
# fix captcha path
%{__perl} -pi -e 's!/lib/ejabberd/priv/bin/captcha.sh!%{_libdir}/%{name}/priv/bin/captcha.sh!g' %{buildroot}/etc/ejabberd/ejabberd.yml

install -D -p -m 0644 %{S:9} %{buildroot}%{_sysconfdir}/pam.d/ejabberdctl
install -D -p -m 0644 %{S:11} %{buildroot}%{_sysconfdir}/pam.d/ejabberd

# install systemd entry
install -D -m 0644 -p %{S:4} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 -p %{S:5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# install config for logrotate
install -D -p -m 0644  %{S:2} %{buildroot}%{_sysconfdir}/logrotate.d/ejabberd

# create room for additional files (such as SQL schemas)
install -d -m 0755 %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
# install sql-scripts for creating db schemes for various RDBMS
install -p -m 0644 sql/lite.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
install -p -m 0644 sql/mssql.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
install -p -m 0644 sql/mysql.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
install -p -m 0644 sql/pg.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/

install -d -m 0755 %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/msgs/
install -p -m 0644 priv/msgs/*.msg %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/msgs/

# Install polkit-related files
install -D -p -m 0644 %{S:12} %{buildroot}%{_datadir}/polkit-1/actions/ejabberdctl.policy
install -D -p -m 0644 %{S:13} %{buildroot}%{_datadir}/polkit-1/rules.d/51-ejabberdctl.rules


%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
useradd -r -g %{name} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -M \
-c "ejabberd" %{name} 2>/dev/null || :


if [ $1 -gt 1 ]; then
    # we should backup DB in every upgrade
    if ejabberdctl status >/dev/null ; then
        # Use timestamp to make database restoring easier
        TIME=$(date +%%Y-%%m-%%dT%%H:%%M:%%S)
        BACKUPDIR=$(mktemp -d -p /var/tmp/ ejabberd-$TIME.XXXXXX)
        chown ejabberd:ejabberd $BACKUPDIR
        BACKUP=$BACKUPDIR/ejabberd-database
        ejabberdctl backup $BACKUP
        # Change ownership to root:root because ejabberd user might be
        # removed on package removal.
        chown -R root:root $BACKUPDIR
        chmod 700 $BACKUPDIR
        echo
        echo The ejabberd database has been backed up to $BACKUP.
        echo
    fi

    # fix cookie path (since ver. 2.1.0 cookie stored in /var/lib/ejabberd/spool
    # rather than in /var/lib/ejabberd
    if [ -f /var/lib/ejabberd/spool/.erlang.cookie ]; then
        cp -pu /var/lib/ejabberd/{spool/,}.erlang.cookie
        echo
        echo The ejabberd cookie file was moved again.
        echo Please delete old one from /var/lib/ejabberd/spool/.erlang.cookie
        echo
    fi
fi


%post
%_post_service %{name}

# Create SSL certificate with default values if it doesn't exist
(cd /etc/ejabberd
if [ ! -f ejabberd.pem ]
then
    echo "Generating SSL certificate /etc/ejabberd/ejabberd.pem..."
    HOSTNAME=$(hostname -s 2>/dev/null || echo "localhost")
    DOMAINNAME=$(hostname -d 2>/dev/null || echo "localdomain")
    openssl req -new -x509 -days 365 -nodes -out ejabberd.pem \
                -keyout ejabberd.pem > /dev/null 2>&1 <<+++
.
.
.
$DOMAINNAME
$HOSTNAME
ejabberd
root@$HOSTNAME.$DOMAINNAME
+++
chown ejabberd:ejabberd ejabberd.pem
chmod 600 ejabberd.pem
fi)


%preun
%_preun_service %{name}

%postun
%_postun_service %{name}

%files
%license COPYING
%doc README README.md

%attr(750,ejabberd,ejabberd) %dir %{_sysconfdir}/ejabberd
%attr(640,ejabberd,ejabberd) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberd.yml
%attr(640,ejabberd,ejabberd) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberdctl.cfg
%attr(640,ejabberd,ejabberd) %config(noreplace) %{_sysconfdir}/ejabberd/inetrc

%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/pam.d/ejabberdctl
%{_datadir}/polkit-1/actions/ejabberdctl.policy
%{_datadir}/polkit-1/rules.d/51-ejabberdctl.rules
%{_bindir}/ejabberdctl

%dir %{_erllibdir}/%{name}-%{version}
%dir %{_erllibdir}/%{name}-%{version}/ebin
%dir %{_erllibdir}/%{name}-%{version}/include
%dir %{_erllibdir}/%{name}-%{version}/priv
%dir %{_erllibdir}/%{name}-%{version}/priv/bin
%dir %{_erllibdir}/%{name}-%{version}/priv/msgs

%{_erllibdir}/%{name}-%{version}/ebin/*.app
%{_erllibdir}/%{name}-%{version}/ebin/*.beam
%{_erllibdir}/%{name}-%{version}/include/*.hrl
%{_erllibdir}/%{name}-%{version}/priv/bin/captcha.sh
%{_erllibdir}/%{name}-%{version}/priv/msgs/*.msg
%{_erllibdir}/%{name}-%{version}/priv/sql/*.sql

%attr(750,ejabberd,ejabberd) %dir /var/lib/ejabberd
%attr(750,ejabberd,ejabberd) %dir %ghost /var/lock/ejabberdctl
%attr(750,ejabberd,ejabberd) %dir /var/log/ejabberd




%changelog
* Sun Jan 08 2017 neoclust <neoclust> 16.09-4.mga6
+ Revision: 1080611
- Bump release to fix a BS failure
- New version 16.09
- new version 16.09

* Sun Oct 16 2016 tv <tv> 16.01-4.mga6
+ Revision: 1061153
- BR systemd-devel for macro definition (mga#12027)

* Mon Jul 18 2016 neoclust <neoclust> 16.01-3.mga6
+ Revision: 1042448
- Rebuild for armv5

* Sun May 08 2016 neoclust <neoclust> 16.01-2.mga6
+ Revision: 1010632
- New version 16.01

  + tv <tv>
    - fix BRs with new erlang
    - fix deps with new erlang

* Wed Mar 02 2016 umeabot <umeabot> 2.1.13-8.mga6
+ Revision: 983366
- Rebuild for openssl

* Mon Feb 08 2016 umeabot <umeabot> 2.1.13-7.mga6
+ Revision: 944412
- Mageia 6 Mass Rebuild

* Fri Oct 17 2014 luigiwalser <luigiwalser> 2.1.13-6.mga5
+ Revision: 779829
- rediff upstream patch to fix CVE-2014-8760

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1.13-4.mga5
+ Revision: 678982
- Mageia 5 Mass Rebuild

* Tue Dec 31 2013 dmorgan <dmorgan> 2.1.13-3.mga4
+ Revision: 563431
- Fix Buildrequires with new texlive

* Tue Oct 22 2013 umeabot <umeabot> 2.1.13-2.mga4
+ Revision: 542900
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 mitya <mitya> 2.1.13-1.mga4
+ Revision: 498016
- New version 2.1.13
- Update patch 3
- Drop patches 9, 10, 11 (merged upstream)

* Sun Mar 24 2013 colin <colin> 2.1.11-8.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Fri Jan 11 2013 umeabot <umeabot> 2.1.11-7.mga3
+ Revision: 349587
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 2.1.11-6.mga3
+ Revision: 321774
- Do not package tmpfiles conf in /etc
- Run systemd-tmpfiles --create on post install

* Fri Oct 26 2012 neoclust <neoclust> 2.1.11-5.mga3
+ Revision: 310285
- Fix config files
- Add systemd support

* Sun Jul 22 2012 neoclust <neoclust> 2.1.11-2.mga3
+ Revision: 273598
- Do not use Mandriva word ( thanks to jean-christophe)

* Sat Jul 07 2012 mitya <mitya> 2.1.11-1.mga3
+ Revision: 268768
- New version 2.1.11

* Mon Apr 23 2012 mitya <mitya> 2.1.10-1.mga2
+ Revision: 233044
- Fix BuildRequires
- Import ejabberd 2.1.10
- Created package structure for ejabberd.

